package util;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;

import static com.nimbusds.jose.util.StandardCharset.UTF_8;

public class HttpClient {

    public static String  doGet(String httpUrl, String auth, int okCode) {
        HttpURLConnection conn = null;
        InputStream inputStream = null;
        BufferedReader bufferedReader = null;
        String result = null;
        try {
            URL url = new URL(httpUrl);
            conn = (HttpURLConnection) url.openConnection();
            conn.setRequestMethod("GET");
            // 设置连接主机服务器的超时时间：15秒
            conn.setConnectTimeout(15000);
            // 设置读取远程返回的数据时间：60秒
            conn.setReadTimeout(60000);
            conn.setRequestProperty("Authorization", "Bearer " + auth);
            conn.connect();
            if (conn.getResponseCode() == okCode) {
                inputStream = conn.getInputStream();
                bufferedReader = new BufferedReader(new InputStreamReader(inputStream, UTF_8));
                StringBuilder stringBuilder = new StringBuilder();
                String tmp;
                while ((tmp = bufferedReader.readLine()) != null) {
                    stringBuilder.append(tmp);
                    stringBuilder.append("\r\n");
                }
                result = stringBuilder.toString();
            } else {
                System.out.println("error:" + conn.getResponseCode());
            }
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            // 关闭资源
            if (null != bufferedReader) {
                try {
                    bufferedReader.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }

            if (null != inputStream) {
                try {
                    inputStream.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }

            if (null != conn) {
                conn.disconnect();
            }
        }

        return result;
    }

    public static String doPost(String httpUrl, String auth, int okCode, String param) {

        HttpURLConnection conn = null;
        InputStream inputStream = null;
        OutputStream outputStream = null;
        BufferedReader bufferedReader = null;
        String result = null;
        try {
            URL url = new URL(httpUrl);
            conn = (HttpURLConnection) url.openConnection();
            conn.setRequestMethod("POST");
            // 设置连接主机服务器超时时间：15秒
            conn.setConnectTimeout(15000);
            // 设置读取主机服务器返回数据超时时间：60秒
            conn.setReadTimeout(60000);
            conn.setDoOutput(true);
            conn.setDoInput(true);
            conn.setRequestProperty("Content-Type", "application/json");
            conn.setRequestProperty("Authorization", "Bearer " + auth);
            outputStream = conn.getOutputStream();
            outputStream.write(param.getBytes());
            if (conn.getResponseCode() == okCode) {
                inputStream = conn.getInputStream();
                bufferedReader = new BufferedReader(new InputStreamReader(inputStream, UTF_8));

                StringBuilder stringBuilder = new StringBuilder();
                String tmp;
                while ((tmp = bufferedReader.readLine()) != null) {
                    stringBuilder.append(tmp);
                    stringBuilder.append("\r\n");
                }
                result = stringBuilder.toString();
            } else {
                System.out.println("error:" + conn.getResponseCode());
            }
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            // 关闭资源
            if (null != bufferedReader) {
                try {
                    bufferedReader.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }

            if (null != outputStream) {
                try {
                    outputStream.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }

            if (null != inputStream) {
                try {
                    inputStream.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }

            if (null != conn) {
                conn.disconnect();
            }
        }
        return result;
    }

    public static String  doDelete(String httpUrl, String auth, int okCode) {
        HttpURLConnection conn = null;
        InputStream inputStream = null;
        BufferedReader bufferedReader = null;
        String result = null;
        try {
            URL url = new URL(httpUrl);
            conn = (HttpURLConnection) url.openConnection();
            conn.setRequestMethod("DELETE");
            // 设置连接主机服务器的超时时间：15秒
            conn.setConnectTimeout(15000);
            // 设置读取远程返回的数据时间：60秒
            conn.setReadTimeout(60000);
            conn.setRequestProperty("Authorization", "Bearer " + auth);
            conn.connect();
            if (conn.getResponseCode() == okCode) {
                inputStream = conn.getInputStream();
                bufferedReader = new BufferedReader(new InputStreamReader(inputStream, UTF_8));
                StringBuilder stringBuilder = new StringBuilder();
                String tmp;
                while ((tmp = bufferedReader.readLine()) != null) {
                    stringBuilder.append(tmp);
                    stringBuilder.append("\r\n");
                }
                result = stringBuilder.toString();
            } else {
                System.out.println("error:" + conn.getResponseCode());
            }
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            // 关闭资源
            if (null != bufferedReader) {
                try {
                    bufferedReader.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }

            if (null != inputStream) {
                try {
                    inputStream.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }

            if (null != conn) {
                conn.disconnect();
            }
        }

        return result;
    }
}