package util;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.nimbusds.jose.JOSEObjectType;
import com.nimbusds.jose.JWSAlgorithm;
import com.nimbusds.jose.JWSHeader;
import com.nimbusds.jose.crypto.RSASSASigner;
import com.nimbusds.jose.jwk.RSAKey;
import com.nimbusds.jose.shaded.json.parser.JSONParser;
import com.nimbusds.jwt.JWTClaimsSet;
import com.nimbusds.jwt.SignedJWT;

import java.security.interfaces.RSAPrivateKey;
import java.util.Date;

public class SignUtil {
    public static String generateJWT(String kid, String serviceAccount) {
        try {
            //注意：这里获取到的时间戳需要是东8区的当前时间。
            long now = System.currentTimeMillis();
            JSONObject jwkJsonObj = JSON.parseObject(serviceAccount);
            String clientId = jwkJsonObj.getString("clientId");
            RSAPrivateKey privateKey = getPrivateKey(jwkJsonObj.getString("privateKey"));
            if (null == privateKey) {
                return null;
            }

            JWTClaimsSet.Builder claimsBuilder = new JWTClaimsSet.Builder()
                    .audience("contacts")
                    .expirationTime(new Date(now + 600000))  //Token的过期时间，此处为10分钟。
                    .issueTime(new Date(now))
                    .issuer(clientId)
                    .claim("account_type","serviceAccount");
            JWSHeader header = new JWSHeader.Builder(JWSAlgorithm.parse("RS256"))
                    .keyID(kid)
                    .type(JOSEObjectType.JWT)
                    .build();
            SignedJWT signedJWT = new SignedJWT(header, claimsBuilder.build());
            signedJWT.sign(new RSASSASigner(privateKey));
            return signedJWT.serialize();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    private static RSAPrivateKey getPrivateKey(String privateKey) throws Exception {
        Object privateKeyObj = new JSONParser(JSONParser.USE_HI_PRECISION_FLOAT | JSONParser.ACCEPT_TAILLING_SPACE).parse(privateKey);
        if (privateKeyObj instanceof com.nimbusds.jose.shaded.json.JSONObject) {
            com.nimbusds.jose.shaded.json.JSONObject jwtObject = (com.nimbusds.jose.shaded.json.JSONObject) privateKeyObj;
            // Find the RSA signing key
            if (jwtObject.get("use").equals("sig") && jwtObject.get("kty").equals("RSA")) {
                return RSAKey.parse(jwtObject).toRSAPrivateKey();
            }
        }
        return null;
    }
}
